@@ -34,7 +34,7 @@ class Clip(NewReferenceObject):
         '_scale_roller'
     ]
 
-    SAVE_AS_REFERENCES = [ 'track', 'scene', 'patterns', 'scales' ]
+    SAVE_AS_REFERENCES = [ 'track', 'scene', 'patterns', 'scales', 'transforms' ]
 
 
     def __init__(self, name=None, scales=None, patterns=None, transforms=None,  rate=1, repeat=-1,
@@ -175,6 +175,7 @@ class Clip(NewReferenceObject):
     # ==================================================================================================================
 
     def _notes_to_events(self, chords):
+
         # given a 1d list of chords, return the list of events with their time info
         # processing tie events along the way and also delay metadata
 
@@ -184,7 +185,7 @@ class Clip(NewReferenceObject):
         # FIXME: this should be modified to keep the subsystem as chords the whole time
         # through the first part
 
-        # FIXME: move first part into function
+        # FIXME: smaller functions
 
         for slot in chords:
 
@@ -220,36 +221,39 @@ class Clip(NewReferenceObject):
 
         for chord in new_chords:
 
-            if not chord.notes[0].repeat:
+            repeats = chord.notes[0].repeat
+
+            if not repeats:
 
                 event1 = Event(type=NOTE_ON, note=chord,time=int(chord.notes[0].start_time))
                 events.append(event1)
 
             else:
 
-                chord_notes = []
+                delta = (chord.notes[0].end_time - chord.notes[0].start_time) / (repeats + 1)
 
-                delta = (note.end_time - note.start_time) / (note.repeat + 1)
-
-                for x in range(0, note.repeat):
-
-                    n1 = note.copy()
-                    n1.length = delta
-                    n1.start_time = note.start_time + (x*delta)
-                    n1.end_time = n1.start_time + delta
-
-                    if x == note.repeat:
-                        n1.length = n1.length + tie_bonus
-                        n1.end_time = n1.end_time + tie_bonus
+                for x in range(0, repeats):
 
 
-                    chord_notes.append(n1)
+                    for (j, note) in enumerate(chord.notes):
 
-                event2 = Event(type=NOTE_ON, note=Chord(notes=chord_notes), time=int(n1.start_time))
-                events.append(event2)
+                        n1 = note.copy()
+                        n1.start_time = int(note.start_time + (x*delta))
+                        n1.end_time = int(n1.start_time + delta - 1)
+                        n1.length = delta - 2
+
+                        if x == note.repeat:
+                            n1.length = n1.length + tie_bonus - 1
+                        n1.end_time = n1.end_time + tie_bonus - 1
+
+                        event2 = Event(type=NOTE_ON, note=Chord(notes=[n1]), time=int(n1.start_time))
+
+                        events.append(event2)
 
         return events
 
+    # FIXME: it is no longer true that all inputs will be chords, process deferred exprs with NOTES?
+
     # ==================================================================================================================
 
     def _get_pattern_chord_list(self, song, t_start, pattern):
