@@ -24,6 +24,10 @@ class Event(object):
         self.time = time
         self.on_event = on_event
         self.from_context = from_context
+
+        if instruments is None:
+            instruments = []
+
         self.instruments = instruments
 
     def __repr__(self):
