@@ -27,7 +27,11 @@ class Deferrable(object):
         self.function = function
 
     def evaluate(self, track, note):
-        return self.function(context=self.context, track=track, subject=note, how=self.how)
+        print("FN=%s" % self.function)
+        print("HOW=%s" % self.how)
+        result = self.function(context=self.context, track=track, subject=note, how=self.how)
+        print("DEFERRABLE: %s" % result)
+        return result
 
 class BaseSlot(object):
 
@@ -247,15 +251,19 @@ def defer_track_grab(context=None, track=None, subject=None, how=None):
     new_note = subject.replace_with_note(playing.name, playing.octave)
 
     if new_note is None:
-        return new_note
+        print("** DEFERRED GRAB MISS **")
+        return None
 
     first = subject
     if first.octave_set_recorded is not None:
         new_note = subject.with_octave(first.octave_set_recorded)
+
     new_note = subject.transpose(octaves=first.octave_shifts_recorded)
+
     if playing.from_scale:
         new_note = subject.scale_transpose(playing.from_scale, first.degree_shifts_recorded)
 
+    print("** GRABBED: %s" % new_note)
     return new_note
 
 
