@@ -9,15 +9,15 @@
 
 import json
 
-from ..api import exceptions
-from .base import NewReferenceObject
-from .scale import Scale
+from warpseq.model.base import NewReferenceObject
 
 FORMAT_VERSION = 0.1
 
 class Song(NewReferenceObject):
 
-    __slots__ = [ 'name', 'clips', 'scale', 'tempo', 'devices', 'instruments', 'scales', 'scenes', 'tracks',
+    # FIXME: warning slot order might matter as it is used by the serializer
+
+    __slots__ = [ 'name',  'devices', 'instruments', 'tracks', 'clips', 'scale', 'tempo',  'scales', 'scenes',
                   'transforms', 'patterns', 'data_pools', 'obj_id' ]
 
     SAVE_AS_REFERENCES = []
@@ -86,6 +86,7 @@ class Song(NewReferenceObject):
         """
         Returns the scene with the given object ID.
         """
+        print("SCENES: %s" % self.scenes)
         matching = [ x for x in self.scenes if str(x.obj_id) == str(obj_id) ]
         if len(matching) == 0:
             return None
@@ -98,6 +99,12 @@ class Song(NewReferenceObject):
         matching = [ x for x in self.tracks if str(x.obj_id) == str(obj_id) ]
         if len(matching) == 0:
             return None
+
+        #print("FOUND A TRACK")
+        #print("*********")
+        #print("INST=%s" % matching[0].instruments)
+        #raise Exception("STOP!")
+
         return matching[0]
 
     def find_clip(self, obj_id):
@@ -154,28 +161,12 @@ class Song(NewReferenceObject):
         Returns the data for the entire song file.
         This can be reversed with from_dict.
         """
-        from . base import COUNTER
-        result = dict(
-            obj_id = self.obj_id,
-            FORMAT_VERSION = FORMAT_VERSION,
-            OBJ_COUNTER = COUNTER,
-            name = self.name,
-            tempo = self.tempo,
-            devices = { str(k) :  v.to_dict() for (k,v) in self.devices.items() },
-            instruments = { str(k) : v.to_dict() for (k, v) in self.instruments.items()},
-            scales = { str(k) :  v.to_dict() for (k, v) in self.scales.items()},
-            scenes = [ v.to_dict() for v in self.scenes ],
-            tracks = [ v.to_dict() for v in self.tracks ],
-            transforms = { str(k) : v.to_dict() for (k, v) in self.transforms.items()},
-            patterns = { str(k) : v.to_dict() for (k, v) in self.patterns.items()},
-            data_pools = {str(k): v.to_dict() for (k, v) in self.data_pools.items()},
-            clips = { str(k) : v.to_dict() for (k,v) in self.clips.items() }
-        )
-        if self.scale:
-            result['scale'] = self.scale.obj_id
-        else:
-            result['scale'] = None
-        return result
+        global FORMAT_VERSION
+        data = super().to_dict()
+        data['FORMAT_VERSION'] = FORMAT_VERSION
+        data['OBJ_COUNTER'] = NewReferenceObject.new_object_id()
+        #print("SONG=%s" % json.dumps(data, sort_keys=True, indent=4))
+        return data
 
     def to_json(self):
         """
@@ -185,6 +176,10 @@ class Song(NewReferenceObject):
 
     @classmethod
     def from_dict(cls, data):
+
+
+        # FIXME: TODO: we should be able to use the deserializer here too?
+
         """
         Loads a song from a dictionary.
         This must support PAST but not FUTURE versions of the program.
