@@ -28,6 +28,10 @@ def roller(alist):
         for item in alist:
             yield item
 
+def forever(item):
+    while True:
+        yield item
+
 def index_where_exceeds(alist, item):
     index = None
     for (i, x) in enumerate(alist):
